// PULL TO REFRESH
Ext.apply(Ext.anims, {
    rotate: new Ext.Anim({
        autoClear: false,
        out: false,
        before: function(el) {
            var d = '';
            if (this.dir == 'ccw'){
              d = '-';
            }

            this.from = {
                '-webkit-transform': 'rotate('+d+''+this.fromAngle+'deg)'
            };

            this.to = {
                '-webkit-transform': 'rotate('+d+''+this.toAngle+'deg)'
            };
                        
        }
    })
});  

Ext.ns('Ext.ux.touch');
/**
 * @author Shea Frederick - http://www.vinylfox.com - Concept and Style/Images from enormego's EGOTableViewPullRefresh
 * @class Ext.ux.touch.ListPullRefresh
 * <p>A plugin that creates 'pull to refresh' functionality in List and DataView components.</p>
 * <p>Sample Usage</p>
 * <pre><code>
 {
     xtype: 'list',
     ...,
     plugins: [new Ext.ux.touch.ListPullRefresh({
       reloadFn: function(cb,scope){
         // do whatever needs to happen for reload
         // then call the cb function passed in
         // cb.call(this);
       }
     })],
     ...
 }
 * </code></pre>
 */
Ext.ux.touch.ListPullRefresh = Ext.extend(Ext.util.Observable, {
  constructor: function(config){
    Ext.apply(this,config);
    this.addEvents({
      'released': true
    });
    Ext.ux.touch.ListPullRefresh.superclass.constructor.call(this, config);
  },
  langPullRefresh: 'Trascina per cancellare...',
  langReleaseRefresh: 'Rilascia per cancellare...',
  langLoading: 'Loading...',
  loading: false,
  // private
  init: function(cmp){
    this.cmp = cmp;
    this.lastUpdate = new Date();
    cmp.loadingText = undefined;
    cmp.on('render', this.initPullHandler, this);
  },
  // private
  initPullHandler: function(){
    this.pullTpl = new Ext.XTemplate(
      '<div class="pullrefresh" style="height: {h}; text-align: bottom;">'+
        '<div class="msgwrap" style="height: 75px; bottom: 0px; position: relative;">'+
          '<span class="arrow {s}"></span>'+
          '<span class="msg">{m}</span>'+
         // '<span class="lastupdate">Last Updated: {[Ext.util.Format.date(values.l,"m/d/Y h:iA")]}</span>'+
        '</div>'+
      '</div>');
    this.pullEl = this.pullTpl.insertBefore(this.cmp.scroller.el, {h:0,m:this.langPullRefresh,l:this.lastUpdate}, true);
    this.pullEl.hide();
    Ext.Element.cssTranslate(this.pullEl, {x:0, y:-90});
    this.cmp.scroller.on('offsetchange', this.handlePull, this);
  },
  //private
  handlePull: function(scroller, offset){
    if (scroller.direction === 'vertical' ){ //&& !this.loading rimosso
      if (offset.y > 0){
        Ext.Element.cssTranslate(this.pullEl, {x:0, y:offset.y-90});
        if (offset.y > 75){
          // state 1
          if (this.state !== 1){
            this.prevState = this.state;
            this.state = 1;
            this.pullTpl.overwrite(this.pullEl, {h:offset.y,m:this.langReleaseRefresh,l:this.lastUpdate});
            Ext.Anim.run(this.pullEl.select('.arrow').first(),'rotate',{dir:'ccw',fromAngle:0,toAngle:180});
          }
        }else if (!scroller.isDragging()){
          // state 3
          if (this.state !== 3){
            this.prevState = this.state;
            this.state = 3;
            if (this.prevState == 1){
              this.loading = true;
              this.lastUpdate = new Date();
              this.pullEl.hide();
              this.fireEvent('released',this,this.cmp);
            }
          }
        }else{
          // state 2
          if (this.state !== 2){
            this.prevState = this.state;
            this.state = 2;
            this.pullTpl.overwrite(this.pullEl, {h:offset.y,m:this.langPullRefresh,l:this.lastUpdate});
            this.pullEl.show();
            if (this.prevState == 1){
              Ext.Anim.run(this.pullEl.select('.arrow').first(),'rotate',{dir:'cw',fromAngle:180,toAngle:0});
            }
          }
        }
      }
    }
  },
  //private
  processComplete: function(){
    this.loading = false; 
    this.lastUpdate = new Date();
    this.pullTpl.overwrite(this.pullEl, {h:0,m:this.langPullRefresh,l:this.lastUpdate});
  }
});

Ext.preg('listpullrefresh', Ext.ux.touch.ListPullRefresh);
// END - PULL TO REFRESH

//START - XML FIX
Ext.override( Ext.data.XmlReader, {
    createAccessor: function() {
        var selectValue = function(key, root, defaultValue){
                        if( key == '#' ){
                                return root.tagName;
                        }
                        if( key.indexOf( '@' ) != -1 ){
                                var property = key.split( '@' )[ 1 ];
                                key = key.split( '@' )[ 0 ];
                        }
                        var val;
                        if( key.length ){
                        		if(key == '.'){
                        			 var node = root.firstChild;
                        		}else{
	                                var node = Ext.DomQuery.selectNode(key, root);
	                                if( node && node.firstChild ){
	                                        node = node.firstChild;
	                                }
                        		}
                        }
                        else{
                                var node = root;
                        }
            if(node){
                                if( typeof( node.getAttribute ) != 'undefined' && typeof( property ) != 'undefined' ){
                                        val = node.getAttribute( property );
                                }
                                else{
                                        val = node.nodeValue;
                                }
            }
            return Ext.isEmpty(val) ? defaultValue : val;
        };

        return function(key) {
            var fn;

            if (key == this.totalProperty) {
                fn = function(root, defaultValue) {
                    var value = selectValue(key, root, defaultValue);
                    return parseFloat(value);
                };
            }

            else if (key == this.successProperty) {
                fn = function(root, defaultValue) {
                    var value = selectValue(key, root, true);
                    return (value !== false && value !== 'false');
                };
            }

            else {
                fn = function(root, defaultValue) {
                    return selectValue(key, root, defaultValue);
                };
            }

            return fn;
        };
    }(),
});
//END - XML FIX       

//FIX BOTTONI PER TEMPLATE
(function () {
    var originalOverwrite = Ext.XTemplate.prototype.overwrite;

    Ext.override(Ext.XTemplate, {
        overwrite: function () {
            //execute the base overwrite method
            originalOverwrite.apply(this, arguments);

            //then, render any components that addCmp might have added
            while (this.templateComponents.length > 0) {
                var el = this.templateComponents.shift();
                if (Ext.get(el.renderTo) != null) {
                    var newel = new Ext.create(el);
                }
            }
        },

        //an array to store the initialconfigs of the components-to-be
        templateComponents:[],
        templateIdCount:0,

        //Pushes an initialConfig to the array so that
        //a component can be later created and rendered.
        //It also generates a div container for the component 
        //with a random id if no id was provided
        addCmp: function (initConfig) {
            var wrapperId = "ext-comp-wrapper-";
            if (initConfig.id != void (0)) {
                wrapperId += initConfig.id;
            } else {
                //wrapperId += Math.random().toString().replace(".", "");
                wrapperId += (this.templateIdCount++).toString() + Math.random().toString().replace(".", "");
            }
            initConfig.renderTo = wrapperId;
            this.templateComponents.push(initConfig);
            //return '<div id="' + wrapperId + '"' + (initConfig.width == void(0) ? '' : ' style="width:'+ initConfig.width +'px"') + '></div>';
            return '<div id="' + wrapperId + '" class="y-wrapper"></div>';
        },

        addCmpTo: function (container, initConfig, collection) {

            if (collection == void(0)){
                this.addCmpTo(container, initConfig, this.templateComponents);
            } else {
                if (collection.length > 0){
                    for (var i=0; i<collection.length; i++){
                        if (collection[i].id == container){
                            if (collection[i].items == void(0)){
                                collection[i].items = [];
                            }
                            collection[i].items.push(initConfig);
                            break;
                        }
                        if (collection[i].items != void(0)){
                            this.addCmpTo(container, initConfig, collection[i].items);
                        }
                    } 
                }
            }

            return;
        }
    });
})();
//FIX

function watchLocation(successCallback, errorCallback) {
  successCallback = successCallback || function(){};
  errorCallback = errorCallback || function(){};

  // Try HTML5-spec geolocation.
  var geolocation = navigator.geolocation;

  if (geolocation) {
    // We have a real geolocation service.
    try {
      function handleSuccess(position) {
        successCallback(position.coords);
      }

      geolocation.watchPosition(handleSuccess, errorCallback, {
        enableHighAccuracy: true,
        maximumAge: 5000 // 5 sec.
      });
    } catch (err) {
      errorCallback();
    }
  } else {
    errorCallback();
  }
}

var latitude = '';
var longitude = '';

function init() {
	  watchLocation(function(coords) {
		  latitude = coords.latitude;
			longitude = coords.longitude;
			var store = Ext.getCmp("outletlist").list.store;
			store.each(function(rec) {
			          rec.updateDistanceFrom(latitude, longitude);
			          
			});
	  }, function() {
	    //error
	  });
	}
init();

/**
* @param {google.maps.LatLng} newLatLng
* @returns {number}
*/
google.maps.LatLng.prototype.distanceFrom = function(newLatLng) {
   var lat1 = this.lat();
   var radianLat1 = lat1 * ( Math.PI  / 180 );
   var lng1 = this.lng();
   var radianLng1 = lng1 * ( Math.PI  / 180 );
   var lat2 = newLatLng.lat();
   var radianLat2 = lat2 * ( Math.PI  / 180 );
   var lng2 = newLatLng.lng();
   var radianLng2 = lng2 * ( Math.PI  / 180 );
   var earth_radius = 6378.1; 
   var diffLat =  ( radianLat1 - radianLat2 );
   var diffLng =  ( radianLng1 - radianLng2 );
   var sinLat = Math.sin( diffLat / 2  );
   var sinLng = Math.sin( diffLng / 2  ); 
   var a = Math.pow(sinLat, 2.0) + Math.cos(radianLat1) * Math.cos(radianLat2) * Math.pow(sinLng, 2.0);
   var distance = earth_radius * 2 * Math.asin(Math.min(1, Math.sqrt(a)));
   return distance;
}

var storeLocalRicerca = new Ext.data.Store({
    model: "localRicerca",
    autoLoad: true,
    proxy: {
        type: 'localstorage',
        id: 'idRicerca',
        proxy: {
            idProperty: 'id'
        }
    },
    sorters: [
              {
                  property : 'id',
                  direction: 'DESC'
              }
          ]
});


var storeLocalOfferta = new Ext.data.Store({
    model: "localDetail",
    autoLoad: true,
    proxy: {
        type: 'localstorage',
        id: 'idOfferta',
        proxy: {
            idProperty: 'id'
        }
    }
});

Ext.Msg.minHeight = 120;
